@@ -18,6 +18,7 @@ from .structs import (
     Generate,
     GetInput,
     Result,
+    Start,
 )
 
 from .structs.proxies import proxy_turbo_gen_fn
@@ -109,6 +110,9 @@ def turbo(
             # Parameters
             payload: Any = None
 
+            # Yield Start() to indicate start
+            yield Start()
+
             try:
                 while True:
                     # Step through the wrapped generator
